@@ -26,8 +26,8 @@
 #ifndef __ORBITCPP_COMPOUND_SEQUENCE_HH
 #define __ORBITCPP_COMPOUND_SEQUENCE_HH
 
-#include "orbitcpp_types.h"
-#include "orbitcpp_exception.h"
+#include "orbitcpp/orb-cpp/orbitcpp_types.h"
+#include "orbitcpp/orb-cpp/orbitcpp_exception.h"
 #include <orbit/orb-core/corba-defs.h>
 #include <glib.h> // for g_assert
 
@@ -128,10 +128,6 @@ namespace _orbitcpp {
 	    {
 	    }
 	
-	// Size information
-	using Super::length;
-	using Super::maximum;
-	
 	// Size requisition
 	void __length (size_t new_length) {
 	    if (new_length > _max)
@@ -190,10 +186,6 @@ namespace _orbitcpp {
 	    {
 	    }
 	
-	// Size information
-	using Super::length;
-	using Super::maximum;
-	
 	// Size requisition
 	void __length (size_t new_length) {
 	    g_assert (new_length <= _max);
