@@ -64,9 +64,9 @@ CORBA::Object::~Object()
 	ev.propagate_sysex();
 }
 
-CORBA::Object::Object* CORBA::Object::_orbitcpp_wrap(CORBA_Object cobject, bool take_copy /* = false */)
+CORBA::Object* CORBA::Object::_orbitcpp_wrap(CORBA_Object cobject, bool take_copy /* = false */)
 {
-	return new CORBA::Object::Object (cobject, take_copy);
+	return new CORBA::Object (cobject, take_copy);
 }
 
 CORBA::Object_ptr CORBA::Object::_duplicate(Object_ptr o) {
