@@ -26,7 +26,7 @@
 #ifndef __ORBITCPP_SIMPLE_SEQUENCE_HH
 #define __ORBITCPP_SIMPLE_SEQUENCE_HH
 
-#include "orbitcpp_sequence.h"
+#include "orbitcpp/orb-cpp/orbitcpp_sequence.h"
 #include <orbit/orb-core/corba-defs.h>
 
 namespace _orbitcpp {
@@ -118,13 +118,9 @@ namespace _orbitcpp {
 	    Super (other)
 	    {
 	    }
-	
-	// Size information
-	using Super::length;
-	using Super::maximum;
-	
+
 	// Size requisition
-	void length (size_t new_length) {
+	void __length (size_t new_length) {
 	    if (new_length > _max)
 	    {
 		buffer_t buffer_tmp = allocbuf (new_length);
@@ -144,10 +140,6 @@ namespace _orbitcpp {
 	    
 	    _length = new_length;
 	}
-
-	void __length (size_t new_length) {
-	    length (new_length);
-	}
     };
 
     template<class Traits, CORBA::ULong max>
@@ -180,20 +172,12 @@ namespace _orbitcpp {
 	    {
 	    }
 	
-	// Size information
-	using Super::length;
-	using Super::maximum;
-	
 	// Size requisition
-	void length (size_t new_length) {
+	void __length (size_t new_length) {
 	    g_assert (new_length <= _max);
 	    
 	    _length = new_length;
 	}
-	
-	void __length (size_t new_length) {
-	    length (new_length);
-	}
     };
     
 } // namespace _orbitcpp
